/********************************************************************************
** Form generated from reading UI file 'nativeappconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NATIVEAPPCONFIG_H
#define UI_NATIVEAPPCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"
#include "project/widgets/dependencieswidget.h"
#include "projecttargetscombobox.h"
#include "shell/environmentconfigurebutton.h"
#include "util/environmentselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_NativeAppPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *projectTargetRadio;
    ProjectTargetsComboBox *projectTarget;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *executableRadio;
    KUrlRequester *executablePath;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *label_3;
    QLineEdit *arguments;
    QLabel *label_4;
    KUrlRequester *workingDirectory;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *environment;
    KDevelop::EnvironmentConfigureButton *configureEnvironment;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QCheckBox *runInTerminal;
    KComboBox *terminal;
    QLabel *label_6;
    QComboBox *killBeforeStartingAgain;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    KComboBox *dependencyAction;
    QLabel *label_7;
    KDevelop::DependenciesWidget *dependencies;

    void setupUi(QWidget *NativeAppPage)
    {
        if (NativeAppPage->objectName().isEmpty())
            NativeAppPage->setObjectName("NativeAppPage");
        NativeAppPage->resize(539, 737);
        verticalLayout = new QVBoxLayout(NativeAppPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(NativeAppPage);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        projectTargetRadio = new QRadioButton(groupBox);
        projectTargetRadio->setObjectName("projectTargetRadio");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(projectTargetRadio->sizePolicy().hasHeightForWidth());
        projectTargetRadio->setSizePolicy(sizePolicy1);
        projectTargetRadio->setChecked(true);

        horizontalLayout_2->addWidget(projectTargetRadio);

        projectTarget = new ProjectTargetsComboBox(groupBox);
        projectTarget->setObjectName("projectTarget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(projectTarget->sizePolicy().hasHeightForWidth());
        projectTarget->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(projectTarget);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        executableRadio = new QRadioButton(groupBox);
        executableRadio->setObjectName("executableRadio");
        executableRadio->setEnabled(true);

        horizontalLayout_3->addWidget(executableRadio);

        executablePath = new KUrlRequester(groupBox);
        executablePath->setObjectName("executablePath");
        executablePath->setEnabled(false);

        horizontalLayout_3->addWidget(executablePath);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(NativeAppPage);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        arguments = new QLineEdit(groupBox_2);
        arguments->setObjectName("arguments");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, arguments);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        workingDirectory = new KUrlRequester(groupBox_2);
        workingDirectory->setObjectName("workingDirectory");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, workingDirectory);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        environment = new KDevelop::EnvironmentSelectionWidget(groupBox_2);
        environment->setObjectName("environment");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(environment->sizePolicy().hasHeightForWidth());
        environment->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(environment);

        configureEnvironment = new KDevelop::EnvironmentConfigureButton(groupBox_2);
        configureEnvironment->setObjectName("configureEnvironment");

        horizontalLayout->addWidget(configureEnvironment);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(12, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        runInTerminal = new QCheckBox(groupBox_2);
        runInTerminal->setObjectName("runInTerminal");

        horizontalLayout_4->addWidget(runInTerminal);


        formLayout->setLayout(3, QFormLayout::ItemRole::LabelRole, horizontalLayout_4);

        terminal = new KComboBox(groupBox_2);
        terminal->setObjectName("terminal");
        terminal->setEnabled(false);
        sizePolicy2.setHeightForWidth(terminal->sizePolicy().hasHeightForWidth());
        terminal->setSizePolicy(sizePolicy2);
        terminal->setEditable(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, terminal);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_6);

        killBeforeStartingAgain = new QComboBox(groupBox_2);
        killBeforeStartingAgain->setObjectName("killBeforeStartingAgain");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, killBeforeStartingAgain);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(NativeAppPage);
        groupBox_3->setObjectName("groupBox_3");
        formLayout_3 = new QFormLayout(groupBox_3);
        formLayout_3->setObjectName("formLayout_3");
        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        dependencyAction = new KComboBox(groupBox_3);
        dependencyAction->addItem(QString());
        dependencyAction->addItem(QString());
        dependencyAction->addItem(QString());
        dependencyAction->setObjectName("dependencyAction");
        dependencyAction->setFrame(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, dependencyAction);

        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        dependencies = new KDevelop::DependenciesWidget(groupBox_3);
        dependencies->setObjectName("dependencies");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(dependencies->sizePolicy().hasHeightForWidth());
        dependencies->setSizePolicy(sizePolicy4);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, dependencies);


        verticalLayout->addWidget(groupBox_3);

#if QT_CONFIG(shortcut)
        label->setBuddy(projectTargetRadio);
        label_2->setBuddy(executableRadio);
        label_3->setBuddy(arguments);
        label_4->setBuddy(workingDirectory);
        label_5->setBuddy(environment);
        label_8->setBuddy(dependencyAction);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(executablePath, arguments);
        QWidget::setTabOrder(arguments, workingDirectory);
        QWidget::setTabOrder(workingDirectory, environment);

        retranslateUi(NativeAppPage);
        QObject::connect(projectTargetRadio, SIGNAL(toggled(bool)), executablePath, SLOT(setDisabled(bool)));
        QObject::connect(executableRadio, SIGNAL(toggled(bool)), executablePath, SLOT(setEnabled(bool)));
        QObject::connect(runInTerminal, SIGNAL(toggled(bool)), terminal, SLOT(setEnabled(bool)));
        QObject::connect(projectTargetRadio, SIGNAL(toggled(bool)), projectTarget, SLOT(setEnabled(bool)));
        QObject::connect(executableRadio, SIGNAL(toggled(bool)), projectTarget, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(NativeAppPage);
    } // setupUi

    void retranslateUi(QWidget *NativeAppPage)
    {
        groupBox->setTitle(tr2i18n("Executable", "@title:group"));
        label->setText(tr2i18n("Project &target:", "@label:chooser"));
        projectTargetRadio->setText(QString());
        label_2->setText(tr2i18n("E&xecutable:", "@label:chooser"));
        executableRadio->setText(QString());
        executablePath->setPlaceholderText(tr2i18n("executable or /path/to/executable", "@info:placeholder"));
#if QT_CONFIG(tooltip)
        executablePath->setToolTip(tr2i18n("Enter the executable name or the absolute path to the executable file", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Behavior", "@title:group"));
        label_3->setText(tr2i18n("Ar&guments:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        arguments->setToolTip(tr2i18n("<html><head/><body><p>Enter arguments to give to the executable.<br/>You can pass arguments containing space characters by putting them in double-quotes.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Working &directory:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        workingDirectory->setToolTip(tr2i18n("Select a working directory for the executable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("E&nvironment:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        environment->setToolTip(tr2i18n("Select an environment to be used", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        runInTerminal->setToolTip(tr2i18n("<p>By default applications will be run in the background and only their output will be displayed in a tool view. This makes it impossible to interact with applications requiring user input from a terminal emulator. To run such applications, you should use an external terminal.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        runInTerminal->setText(tr2i18n("Use external terminal:", "@option:check"));
#if QT_CONFIG(tooltip)
        terminal->setToolTip(tr2i18n("Define the command to execute the external terminal emulator.<br>\n"
"The path to the executable and its arguments will be appended to this command.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Restart", "@label:listbox"));
        groupBox_3->setTitle(tr2i18n("Dependencies", "@title:group"));
        label_8->setText(tr2i18n("Act&ion:", "@label:listbox"));
        dependencyAction->setItemText(0, tr2i18n("Do Nothing", "@item:inlistbox dependency action"));
        dependencyAction->setItemText(1, tr2i18n("Build", "@item:inlistbox dependency action"));
        dependencyAction->setItemText(2, tr2i18n("Build and Install", "@item:inlistbox dependency action"));

#if QT_CONFIG(tooltip)
        dependencyAction->setToolTip(tr2i18n("Specifies the action to take for the dependencies before starting the executable.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        dependencyAction->setWhatsThis(tr2i18n("The selected action will be run before the executable is started.  This allows there to be parts of a project, upon which the executable does not directly depend, to be built and/or installed before running the application.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_7->setText(tr2i18n("Targets:", "@label:chooser"));
        (void)NativeAppPage;
    } // retranslateUi

};

namespace Ui {
    class NativeAppPage: public Ui_NativeAppPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NATIVEAPPCONFIG_H

